%bcond_with static_libs # don't build static libraries

Summary:        High quality system independent, open source libm
Name:           openlibm
Version:        0.4.1
Release:        2%{?dist}
License:        BSD and MIT and ISC and Public Domain
Group:          System Environment/Libraries
Source0:        https://github.com/JuliaLang/openlibm/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
URL:            https://github.com/JuliaLang/openlibm/
# openlibm does not currently build properly on non-x86 architectures
# https://github.com/JuliaLang/openlibm/issues/18
ExclusiveArch:  %{ix86} x86_64 %{arm}

%description
OpenLIBM is an effort to have a high quality standalone LIBM library.
It is meant to be used standalone in applications and programming language
implementations. The OpenLIBM code derives from the FreeBSD msun implementation,
which in turn derives from FDLIBM 5.3. As a result, it has a number of fixes
and updates that have accumulated over the years in msun, and also optimized
assembly versions of many functions.

%package devel
Summary:    High quality system independent, open source libm
Group:      Development/Libraries
Requires:   %{name}%{?_isa} = %{version}-%{release}

%description devel
Contains header files for developing applications that use the %{name}
library.

%package static
Summary:    High quality system independent, open source libm
Group:      Development/Libraries
Requires:   %{name}-devel%{?_isa} = %{version}-%{release}

%description static
Static %{name} library.

%prep
%setup -q %{name}-%{version}

# File under the Apple Public Source License Version 1.1
rm -f test/ieeetestnew.c
# File under the Apple Public Source License Version 2.0
rm -f i387/osx_asm.h

%build
# openlibm uses the arch name to choose which directory to build
# and the name is "arm"
%ifarch arm7hl
%global arch arm
%else
%global arch %{_arch}
%endif

make %{?_smp_mflags} \
      FFLAGS="%{optflags}" \
      CFLAGS="%{optflags}" \
      ARCH=%{arch}

%check
cd test/

%ifarch x86_64
./test-float
./test-double
%endif

%ifarch %{ix86}
./test-float
# This test fails on i686:
# https://github.com/JuliaLang/openlibm/issues/55
#./test-double
%endif

# Tests fail on ARM:
# https://github.com/JuliaLang/openlibm/issues/83

%install
make install prefix=%{_prefix} \
             libdir=%{_libdir} \
             includedir=%{_includedir} \
             DESTDIR=%{buildroot} \
             ARCH=%{arch}

%if ! %{with static_libs}
rm %{buildroot}/%{_libdir}/libopenlibm.a
%endif

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc LICENSE.md README.md
%{_libdir}/libopenlibm.so.1*

%files devel
%{_libdir}/libopenlibm.so
%{_libdir}/pkgconfig/openlibm.pc
%{_includedir}/openlibm.h
%{_includedir}/openlibm/

%if %{with static_libs}
%files static
%{_libdir}/libopenlibm.a
%endif

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Feb 1 2015 Milan Bouchet-Valat <nalimilan@club.fr> - 0.4.1-1
- New upstream release.
- Run tests on architectures where they are supposed to work thanks to new fixes.

* Sat Oct 25 2014 Peter Robinson <pbrobinson@fedoraproject.org> 0.4-3
- Fix build on armv7hl

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jul 27 2014 Milan Bouchet-Valat <nalimilan@club.fr> - 0.4-1
- New upstream release.
- Fix path of two files to remove.

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 4 2014 Milan Bouchet-Valat <nalimilan@club.fr> - 0.3-6
- Disable tests for now.

* Thu May 1 2014 Milan Bouchet-Valat <nalimilan@club.fr> - 0.3-5
- Add tests.

* Tue Apr 29 2014 Milan Bouchet-Valat <nalimilan@club.fr> - 0.3-4
- Add ISC to list of licenses.
- Add bug reference about the failing tests.

* Mon Apr 21 2014 Milan Bouchet-Valat <nalimilan@club.fr> - 0.3-3
- Use Group System Environment/Libraries for base package.

* Sun Apr 20 2014 Milan Bouchet-Valat <nalimilan@club.fr> - 0.3-2
- Put libopenlibm.so.0 in base package instead of in -devel.

* Sat Apr 19 2014 Milan Bouchet-Valat <nalimilan@club.fr> - 0.3-1
- Initial version.
